@@ -23,8 +23,13 @@ namespace Rcpp{
             }
             
             template <typename Target>
-            inline void apply_parallel( Target& target, int nthreads ) const {
-                data.get_ref().apply_parallel(target, nthreads) ;    
+            void apply_serial( Target& target ){
+                data.get_ref().apply_serial(target) ;  
+            }
+            
+            template <typename Target>
+            inline void apply_parallel( Target& target ) const {
+                data.get_ref().apply_parallel(target) ;    
             }
     
             
